#! /bin/bash

# Moln (moln) is Copyright (C) 2021 Paolo Lulli, Kevwe Technology AB
#
# This file is part of moln.
#
# negentropy is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# negentropy is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#

function ec2_start()
{
  profile=$1
  payload=$2
  aws \
  --profile ${profile}\
  ec2 \
  invoke --function-name ${FUNCTION}\
  --payload \"${payload}\"
}

function ec2_create_security_group()
{
  profile=$1
  security_group=$2
  aws ec2 \
  --profile ${profile}\
  create-security-group --group-name ${security_group}\
  --description "moln-${security_group}"
}

function ec2_firewall_ingress()
{
  profile=$1
  security_group=$2
  aws ec2 \
  --profile ${profile}\
  authorize-security-group-ingress \
  --group-name "${security_group}" \
  --protocol tcp \
  --port 22 \
  --cidr 0.0.0.0/0
}

function ec2_describe_security_group()
{
  profile=$1
  security_group=$2
  aws ec2 \
  --profile ${profile}\
  describe-security-groups \
  --group-names ${security_group}
}

function ec2_create_keypair()
{
  profile=$1
  keyname=$2
  aws ec2 \
  --profile ${profile}\
  create-key-pair --key-name ${keyname} \
  --query 'KeyMaterial' \
  --output text > "${keyname}.pem"
}

function ec2_run_instance()
{
  profile=$1
  group_id=$2
  image_id=$3
  instance_type=$4
  key_name=$5
  shellfile=$6
  aws ec2 \
  --profile ${profile}\
  run-instances --image-id ${image_id} \
  --security-group-ids ${group_id} \
  --instance-type ${instance_type} \
  --key-name ${key_name}\
  --user-data "file://${shellfile}"
}

function ec2_get_instance_ip()
{
  profile=$1
  instance_id=$2
  aws ec2 --profile ${profile} describe-instances \
  --instance-ids ${instance_id} \
  --query 'Reservations[0].Instances[0].PublicIpAddress'
}

function ec2_terminate_instances()
{
  profile=$1
  instance_id=$2
  aws ec2 --profile ${profile} terminate-instances --instance-ids ${instance_id}
}

function ec2_list_instances()
{
  profile=$1
  aws ec2 --profile ${profile} describe-instance-status | jq '.InstanceStatuses[].InstanceId'
}

